==> intel-media-driver-non-free_22.3.1+ds1.orig.tar.xz: media-driver-intel-media-22.3.1/media_softlet/agnostic/common/codec/hal/dec/shared/packet/media_srcs.cmake <==
# Copyright (c) 2020, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
set(TMP_SOURCES_
    ${TMP_SOURCES_}
    ${CMAKE_CURRENT_LIST_DIR}/decode_sub_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_sub_packet_manager.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_predication_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_marker_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_downsampling_packet.cpp
)

set(TMP_HEADERS_
    ${TMP_HEADERS_}
    ${CMAKE_CURRENT_LIST_DIR}/decode_packet_id.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_sub_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_sub_packet_manager.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_predication_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_marker_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_downsampling_packet.h
)

media_add_curr_to_include_path()

==> intel-media-driver-non-free_25.1.4+ds1.orig.tar.xz: media-driver-intel-media-25.1.4/media_softlet/agnostic/common/codec/hal/dec/shared/packet/media_srcs.cmake <==
# Copyright (c) 2020-2022, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.
set(SOFTLET_DECODE_COMMON_SOURCES_
    ${SOFTLET_DECODE_COMMON_SOURCES_}
    ${CMAKE_CURRENT_LIST_DIR}/decode_sub_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_sub_packet_manager.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_predication_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_marker_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_downsampling_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_huc.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_huc_copy_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/decode_av1_aqm_packet.cpp
)

set(SOFTLET_DECODE_COMMON_HEADERS_
    ${SOFTLET_DECODE_COMMON_HEADERS_}
    ${CMAKE_CURRENT_LIST_DIR}/decode_packet_id.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_sub_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_sub_packet_manager.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_predication_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_marker_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_downsampling_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_huc.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_huc_copy_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/decode_av1_aqm_packet.h
)


source_group( CodecHalNext\\Shared\\Decode FILES ${SOFTLET_DECODE_COMMON_SOURCES_} ${SOFTLET_DECODE_COMMON_HEADERS_} )

set(SOFTLET_DECODE_COMMON_PRIVATE_INCLUDE_DIRS_
    ${SOFTLET_DECODE_COMMON_PRIVATE_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)
